From 4400e1f593ea40a51912128adb4f53d59e62cad8 Mon Sep 17 00:00:00 2001
From: John Crispin <blogic@openwrt.org>
Date: Wed, 10 Sep 2014 22:40:18 +0200
Subject: [PATCH 22/36] MTD: m25p80: allow loading mtd name from OF

In accordance with the physmap flash we should honour the linux,mtd-name
property when deciding what name the mtd device has.

Signed-off-by: Thomas Langer <thomas.langer@lantiq.com>
Signed-off-by: John Crispin <blogic@openwrt.org>
---
 drivers/mtd/devices/m25p80.c |    6 ++++++
 1 file changed, 6 insertions(+)

--- a/drivers/mtd/devices/m25p80.c
+++ b/drivers/mtd/devices/m25p80.c
@@ -19,6 +19,7 @@
 #include <linux/errno.h>
 #include <linux/module.h>
 #include <linux/device.h>
+#include <linux/of.h>
 
 #include <linux/mtd/mtd.h>
 #include <linux/mtd/partitions.h>
@@ -198,6 +199,10 @@ static int m25p_probe(struct spi_device
 	enum read_mode mode = SPI_NOR_NORMAL;
 	char *flash_name = NULL;
 	int ret;
+	const char __maybe_unused	*of_mtd_name = NULL;
+
+	of_property_read_string(spi->dev.of_node,
+		"linux,mtd-name", &of_mtd_name);
 
 	data = dev_get_platdata(&spi->dev);
 
@@ -229,6 +234,8 @@ static int m25p_probe(struct spi_device
 
 	if (data && data->name)
 		flash->mtd.name = data->name;
+	else if (of_mtd_name)
+		flash->mtd.name = of_mtd_name;
 
 	/* For some (historical?) reason many platforms provide two different
 	 * names in flash_platform_data: "name" and "type". Quite often name is
